searchData={"content_type":"text/markdown","items":[{"doc":"EventStore adapter for Commanded.\n\nPlease check the [Getting Started](getting-started.html) guide to learn more.","ref":"Commanded.EventStore.Adapters.EventStore.html","title":"Commanded.EventStore.Adapters.EventStore","type":"module"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- Pass `opts` to `append_to_stream` function ([#14](https://github.com/commanded/commanded-eventstore-adapter/pull/14)).","ref":"changelog.html#v1-4-1","title":"v1.4.1 - Changelog","type":"extras"},{"doc":"- Support [Commanded v1.4.0](https://github.com/commanded/commanded/blob/master/CHANGELOG.md#v140) with subscription concurrency ([#10](https://github.com/commanded/commanded-eventstore-adapter/pull/10)).\n\n---","ref":"changelog.html#v1-4-0","title":"v1.4.0 - Changelog","type":"extras"},{"doc":"- Support Commanded v1.2.0\n\n---","ref":"changelog.html#v1-2-0","title":"v1.2.0 - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v1-1-0","title":"v1.1.0 - Changelog","type":"extras"},{"doc":"- Support dynamic event stores ([#6](https://github.com/commanded/commanded-eventstore-adapter/pull/6)).\n- Support Commanded v1.1.0 and EventStore v1.1.0\n\n---","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v1-0-0","title":"v1.0.0 - Changelog","type":"extras"},{"doc":"- Support multiple Commanded apps ([#4](https://github.com/commanded/commanded-eventstore-adapter/pull/4/files)).\n\n---","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-6-0","title":"v0.6.0 - Changelog","type":"extras"},{"doc":"- Support for Commanded v0.19 and EventStore v0.17.\n\n---","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-5-0","title":"v0.5.0 - Changelog","type":"extras"},{"doc":"- Support for Commanded v0.18 and EventStore v0.16.\n\n---","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"#","ref":"changelog.html#v0-4-0","title":"v0.4.0 - Changelog","type":"extras"},{"doc":"- Support for Commanded v0.16 and EventStore v0.14.\n\n---","ref":"changelog.html#enhancements","title":"Enhancements - Changelog","type":"extras"},{"doc":"- Include `event_id` in recorded event data.","ref":"changelog.html#v0-3-0","title":"v0.3.0 - Changelog","type":"extras"},{"doc":"# Getting started\n\nThe package can be installed from hex as follows.\n\n1. Add `commanded_eventstore_adapter` to your list of dependencies in `mix.exs`:\n\n    ```elixir\n    def deps do\n      [{:commanded_eventstore_adapter, \"~> 1.4\"}]\n    end\n    ```\n\n    Then run `mix deps.get`\n\n2. Create an event store for your application:\n\n    ```elixir\n    defmodule MyApp.EventStore do\n      use EventStore, otp_app: :my_app\n    end\n    ```\n\n3. Define and configure your Commanded application to use the `Commanded.EventStore.Adapters.EventStore` adapter and your own event store module:\n\n    ```elixir\n    defmodule MyApp.Application do\n      use Commanded.Application,\n        otp_app: :my_app,\n        event_store: [\n          adapter: Commanded.EventStore.Adapters.EventStore,\n          event_store: MyApp.EventStore\n        ]\n      end\n    ```\n\n4. Configure the event store in each environment's mix config file (e.g. `config/dev.exs`), specifying usage of Commanded's JSON serializer:\n\n    ```elixir\n    import Config\n\n    config :my_app, MyApp.EventStore,\n      serializer: Commanded.Serialization.JsonSerializer,\n      username: \"postgres\",\n      password: \"postgres\",\n      database: \"eventstore_dev\",\n      hostname: \"localhost\",\n      pool_size: 10\n    ```\n\n5. Add your event store to `config/config.exs` to make it easier to use the EventStore mix tasks:\n\n    ```elixir\n    # config/config.exs\n    import Config\n\n    config :my_app, event_stores: [MyApp.EventStore]\n\n    import_config \"#{config_env()}.exs\"\n    ```\n\n6. Create the EventStore database and tables using the `mix` task:\n\n    ```shell\n    mix do event_store.create, event_store.init\n    ```","ref":"getting-started.html","title":"EventStore adapter","type":"extras"},{"doc":"# Dynamic event store\n\nEventStore supports starting multiple instances, each with a unique name. This feature can be used to support multi-tenancy where each tenant's data is stored separately in its own Postgres schema.","ref":"dynamic-event-store.html","title":"Dynamic EventStore","type":"extras"},{"doc":"Define an application which uses the `init/1` callback function to set the event store name and schema from config:\n\n```elixir\ndefmodule MyApp.Application do\n  use Commanded.Application,\n    otp_app: :my_app,\n    event_store: [\n      adapter: Commanded.EventStore.Adapters.EventStore,\n      event_store: MyApp.EventStore\n    ]\n\n  def init(config) do\n    name = Keyword.fetch!(config, :name)\n\n    {tenant, config} = Keyword.pop(config, :tenant)\n\n    # Set dynamic event store name\n    config = put_in(config, [:event_store, :name], Module.concat([name, EventStore])\n\n    # Set event store prefix (Postgres schema)\n    config = put_in(config, [:event_store, :prefix], Atom.to_string(tenant))\n\n    {:ok, config}\n  end\nend\n```\n\nStart an application per tenant:\n\n```elixir\nfor tenant <- [:tenant1, :tenant2, :tenant3] do\n  {:ok, _pid} = MyApp.Application.start_link(name: tenant, tenant: tenant)\nend\n```\n\nEach started application will use its own dynamically named EventStore and separate Postgres schema.","ref":"dynamic-event-store.html#example-usage","title":"Example usage - Dynamic EventStore","type":"extras"}]}